# Metrics
(*metrics*)

## Overview

<span data-status-page="28933"></span>
Metrics are quantitative measurements used to evaluate the performance and activity of cryptocurrency exchanges. These metrics include:

1. Trading Volume: The total amount of cryptocurrency traded on an exchange within a specific time period, indicating liquidity and activity.
1. Market Depth: The level of buy and sell orders at different price levels, providing insights into liquidity and potential price impact.
1. Order Book: A record of outstanding buy and sell orders for a cryptocurrency, reflecting supply and demand dynamics.
1. Spread: The difference between the highest bid and lowest ask prices, indicating liquidity and trading costs.
1. Price Charts: Visual representations of cryptocurrency price movements over time, helping identify trends and inform trading decisions.
1. Market Cap: The total value of a cryptocurrency calculated by its price multiplied by circulating supply, reflecting relative size and value.
1. Trading Pairs: Combinations of cryptocurrencies available for trading, including volume, price, and spread for each pair.
1. User Metrics: Data on active users, new registrations, user retention, and engagement, indicating platform popularity and growth.
1. Trading Fees: Fees charged for executing trades, including fee structure, discounts, and revenue generated by the exchange.
1. Security Metrics: Measures assessing the security of an exchange, such as past incidents, user fund protection, and security audits.

These metrics assist traders and investors in evaluating market activity, liquidity, and the reliability of crypto exchanges for informed decision-making.

### Available Operations

* [get_v1_metrics_listing](#get_v1_metrics_listing) - Listing of all supported metrics by CoinAPI
* [get_v1_metrics_exchange_listing](#get_v1_metrics_exchange_listing) - Listing of all supported exchange metrics
* [get_v1_metrics_exchange_current](#get_v1_metrics_exchange_current) - Current metrics for given exchange
* [get_v1_metrics_exchange_history](#get_v1_metrics_exchange_history) - Historical metrics for the exchange
* [get_v1_metrics_symbol_listing](#get_v1_metrics_symbol_listing) - Listing of all supported metrics for symbol
* [get_v1_metrics_symbol_current](#get_v1_metrics_symbol_current) - Current metrics for given symbol
* [get_v1_metrics_symbol_history](#get_v1_metrics_symbol_history) - Historical metrics for symbol
* [get_v1_metrics_asset_listing](#get_v1_metrics_asset_listing) - Listing of all supported metrics for asset
* [get_v1_metrics_asset_current](#get_v1_metrics_asset_current) - Current metrics for given asset
* [get_v1_metrics_asset_history](#get_v1_metrics_asset_history) - Historical metrics for asset

## get_v1_metrics_listing

Get all data metrics.

### Example Usage

```python
import coinapi

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)


res = s.metrics.get_v1_metrics_listing()

if res.content is not None:
    # handle response
    pass
```


### Response

**[operations.GetV1MetricsListingResponse](../../models/operations/getv1metricslistingresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_exchange_listing

Get data metrics for exchange.

### Example Usage

```python
import coinapi

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)


res = s.metrics.get_v1_metrics_exchange_listing(exchange_id='<value>', metric_id='<value>')

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                                | Type                                                     | Required                                                 | Description                                              |
| -------------------------------------------------------- | -------------------------------------------------------- | -------------------------------------------------------- | -------------------------------------------------------- |
| `exchange_id`                                            | *str*                                                    | :heavy_check_mark:                                       | The exchange identifier (from the Metadata -> Exchanges) |
| `metric_id`                                              | *Optional[str]*                                          | :heavy_minus_sign:                                       | The metric identifier (from the Metrics -> Listing)      |


### Response

**[operations.GetV1MetricsExchangeListingResponse](../../models/operations/getv1metricsexchangelistingresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_exchange_current

Get current exchange metrics values.

### Example Usage

```python
import coinapi

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)


res = s.metrics.get_v1_metrics_exchange_current(exchange_id='<value>', metric_id='<value>')

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                                | Type                                                     | Required                                                 | Description                                              |
| -------------------------------------------------------- | -------------------------------------------------------- | -------------------------------------------------------- | -------------------------------------------------------- |
| `exchange_id`                                            | *str*                                                    | :heavy_check_mark:                                       | The exchange identifier (from the Metadata -> Exchanges) |
| `metric_id`                                              | *Optional[str]*                                          | :heavy_minus_sign:                                       | The metric identifier (from the Metrics -> Listing)      |


### Response

**[operations.GetV1MetricsExchangeCurrentResponse](../../models/operations/getv1metricsexchangecurrentresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_exchange_history

Get exchange metrics history.

### Example Usage

```python
import coinapi
from coinapi.models import operations

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)

req = operations.GetV1MetricsExchangeHistoryRequest(
    metric_id='<value>',
    exchange_id='<value>',
)

res = s.metrics.get_v1_metrics_exchange_history(req)

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                                                                                      | Type                                                                                                           | Required                                                                                                       | Description                                                                                                    |
| -------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------- |
| `request`                                                                                                      | [operations.GetV1MetricsExchangeHistoryRequest](../../models/operations/getv1metricsexchangehistoryrequest.md) | :heavy_check_mark:                                                                                             | The request object to use for the request.                                                                     |


### Response

**[operations.GetV1MetricsExchangeHistoryResponse](../../models/operations/getv1metricsexchangehistoryresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_symbol_listing

Get data metrics for symbol.

### Example Usage

```python
import coinapi

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)


res = s.metrics.get_v1_metrics_symbol_listing(metric_id='<value>', exchange_id='<value>', symbol_id='<value>')

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                            | Type                                                 | Required                                             | Description                                          |
| ---------------------------------------------------- | ---------------------------------------------------- | ---------------------------------------------------- | ---------------------------------------------------- |
| `metric_id`                                          | *Optional[str]*                                      | :heavy_minus_sign:                                   | Metric identifier (from the Metrics -> Listing)      |
| `exchange_id`                                        | *Optional[str]*                                      | :heavy_minus_sign:                                   | Exchange identifier (from the Metadata -> Exchanges) |
| `symbol_id`                                          | *Optional[str]*                                      | :heavy_minus_sign:                                   | Symbol identifier (from the Metadata -> Symbols)     |


### Response

**[operations.GetV1MetricsSymbolListingResponse](../../models/operations/getv1metricssymbollistingresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_symbol_current

Get current symbol metrics.

### Example Usage

```python
import coinapi

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)


res = s.metrics.get_v1_metrics_symbol_current(metric_id='<value>', symbol_id='<value>', exchange_id='<value>')

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                        | Type                                             | Required                                         | Description                                      |
| ------------------------------------------------ | ------------------------------------------------ | ------------------------------------------------ | ------------------------------------------------ |
| `metric_id`                                      | *Optional[str]*                                  | :heavy_minus_sign:                               | Metric identifier (from the Metrics -> Listing)  |
| `symbol_id`                                      | *Optional[str]*                                  | :heavy_minus_sign:                               | Symbol identifier (from the Metadata -> Symbols) |
| `exchange_id`                                    | *Optional[str]*                                  | :heavy_minus_sign:                               | Exchange id (from the Metadata -> Exchanges)     |


### Response

**[operations.GetV1MetricsSymbolCurrentResponse](../../models/operations/getv1metricssymbolcurrentresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_symbol_history

Get symbol metrics history.

### Example Usage

```python
import coinapi
from coinapi.models import operations

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)

req = operations.GetV1MetricsSymbolHistoryRequest(
    metric_id='<value>',
    symbol_id='<value>',
)

res = s.metrics.get_v1_metrics_symbol_history(req)

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                                                                                  | Type                                                                                                       | Required                                                                                                   | Description                                                                                                |
| ---------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------- | ---------------------------------------------------------------------------------------------------------- |
| `request`                                                                                                  | [operations.GetV1MetricsSymbolHistoryRequest](../../models/operations/getv1metricssymbolhistoryrequest.md) | :heavy_check_mark:                                                                                         | The request object to use for the request.                                                                 |


### Response

**[operations.GetV1MetricsSymbolHistoryResponse](../../models/operations/getv1metricssymbolhistoryresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_asset_listing

Get data metrics for asset.

### Example Usage

```python
import coinapi
from coinapi.models import operations

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)

req = operations.GetV1MetricsAssetListingRequest()

res = s.metrics.get_v1_metrics_asset_listing(req)

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                                                                                | Type                                                                                                     | Required                                                                                                 | Description                                                                                              |
| -------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- |
| `request`                                                                                                | [operations.GetV1MetricsAssetListingRequest](../../models/operations/getv1metricsassetlistingrequest.md) | :heavy_check_mark:                                                                                       | The request object to use for the request.                                                               |


### Response

**[operations.GetV1MetricsAssetListingResponse](../../models/operations/getv1metricsassetlistingresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_asset_current

Get current asset metrics.

### Example Usage

```python
import coinapi

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)


res = s.metrics.get_v1_metrics_asset_current(metric_id='<value>', asset_id='<value>', asset_id_external='<value>', exchange_id='<value>')

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                            | Type                                                 | Required                                             | Description                                          |
| ---------------------------------------------------- | ---------------------------------------------------- | ---------------------------------------------------- | ---------------------------------------------------- |
| `metric_id`                                          | *Optional[str]*                                      | :heavy_minus_sign:                                   | Metric identifier (from the Metrics -> Listing)      |
| `asset_id`                                           | *Optional[str]*                                      | :heavy_minus_sign:                                   | Asset identifier (from the Metadata -> Assets)       |
| `asset_id_external`                                  | *Optional[str]*                                      | :heavy_minus_sign:                                   | Exchange asset identifier                            |
| `exchange_id`                                        | *Optional[str]*                                      | :heavy_minus_sign:                                   | Exchange identifier (from the Metadata -> Exchanges) |


### Response

**[operations.GetV1MetricsAssetCurrentResponse](../../models/operations/getv1metricsassetcurrentresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |

## get_v1_metrics_asset_history

Get asset metrics history.

### Example Usage

```python
import coinapi
from coinapi.models import operations

s = coinapi.CoinAPI(
    api_key="<YOUR_API_KEY_HERE>",
)

req = operations.GetV1MetricsAssetHistoryRequest(
    metric_id='<value>',
    exchange_id='<value>',
)

res = s.metrics.get_v1_metrics_asset_history(req)

if res.content is not None:
    # handle response
    pass
```

### Parameters

| Parameter                                                                                                | Type                                                                                                     | Required                                                                                                 | Description                                                                                              |
| -------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------- |
| `request`                                                                                                | [operations.GetV1MetricsAssetHistoryRequest](../../models/operations/getv1metricsassethistoryrequest.md) | :heavy_check_mark:                                                                                       | The request object to use for the request.                                                               |


### Response

**[operations.GetV1MetricsAssetHistoryResponse](../../models/operations/getv1metricsassethistoryresponse.md)**
### Errors

| Error Object    | Status Code     | Content Type    |
| --------------- | --------------- | --------------- |
| errors.CoinAPIError | 4x-5xx          | */*             |
